@@ -74,7 +74,11 @@ struct _GcalYearViewPrivate
    * 0 for Sunday, 1 for Monday and so on */
   gint          first_weekday;
 
-  /**
+  /* first and last weeks of the year */
+  guint         first_week_of_year;
+  guint         last_week_of_year;
+
+    /**
    * clock format from GNOME desktop settings
    */
   gboolean      use_24h_format;
@@ -539,13 +543,18 @@ draw_month_grid (GcalYearView *year_view,
 
   cairo_save (cr);
   context = gtk_widget_get_style_context (widget);
-  state_flags = gtk_widget_get_state_flags (widget);
+  state_flags = gtk_style_context_get_state (context);
   sw = 1 - 2 * priv->k;
   box_side = priv->navigator_grid->box_side;
   x = priv->navigator_grid->coordinates[month_nr].x;
   y = priv->navigator_grid->coordinates[month_nr].y;
 
+  /* Get the font description */
+  gtk_style_context_save (context);
+  gtk_style_context_set_state (context, state_flags | GTK_STATE_FLAG_SELECTED);
   gtk_style_context_get (context, state_flags | GTK_STATE_FLAG_SELECTED, "font", &sfont_desc, NULL);
+  gtk_style_context_restore (context);
+
   slayout = gtk_widget_create_pango_layout (widget, NULL);
   pango_layout_set_font_description (slayout, sfont_desc);
 
@@ -714,9 +723,15 @@ draw_month_grid (GcalYearView *year_view,
 
   for (i = 0; i < shown_rows; i++)
     {
-      if (i == 0)
+      /* special condition for first and last weeks of the year */
+      if (month_nr == 0 && priv->first_week_of_year > 1 && i == 1)
+        *weeks_counter = 1;
+      else if (month_nr == 11 && (i + 1) == shown_rows)
+        *weeks_counter = priv->last_week_of_year;
+      /* other weeks */
+      else if (i == 0)
         {
-          if (days_delay == 0)
+          if (days_delay == 0 && month_nr != 0)
             *weeks_counter = *weeks_counter + 1;
         }
       else
@@ -759,6 +774,7 @@ draw_navigator (GcalYearView *year_view,
   gint header_padding_left, header_padding_top, header_height, layout_width, layout_height;
   gint real_padding_left, real_padding_top, i, sw, weeks_counter;
   gdouble width, height, box_side;
+  GDate day_of_year;
 
   gchar *header_str;
 
@@ -767,7 +783,7 @@ draw_navigator (GcalYearView *year_view,
 
   priv = year_view->priv;
   context = gtk_widget_get_style_context (GTK_WIDGET (year_view));
-  state_flags = gtk_widget_get_state_flags (GTK_WIDGET (year_view));
+  state_flags = gtk_style_context_get_state (context);
   sw = 1 - 2 * priv->k;
   width = gtk_widget_get_allocated_width (widget);
 
@@ -784,7 +800,7 @@ draw_navigator (GcalYearView *year_view,
 
   /* draw header on navigator */
   context = gtk_widget_get_style_context (widget);
-  state_flags = gtk_widget_get_state_flags (GTK_WIDGET (year_view));
+  state_flags = gtk_style_context_get_state (context);
 
   header_layout = gtk_widget_create_pango_layout (widget, header_str);
   pango_layout_set_font_description (header_layout, font_desc);
@@ -810,7 +826,13 @@ draw_navigator (GcalYearView *year_view,
   real_padding_top = (height - (7 * 3 * box_side)) / 4.0;
 
   priv->navigator_grid->box_side = box_side;
-  weeks_counter = 1;
+
+  /* get first and last weeks of the year */
+  g_date_set_dmy (&day_of_year, 1, G_DATE_JANUARY, priv->date->year);
+  priv->first_week_of_year = g_date_get_iso8601_week_of_year (&day_of_year);
+  g_date_set_dmy (&day_of_year, 31, G_DATE_DECEMBER, priv->date->year);
+  priv->last_week_of_year = g_date_get_iso8601_week_of_year (&day_of_year);
+  weeks_counter = priv->first_week_of_year;
   for (i = 0; i < 12; i++)
     {
       gint row = i / 4;
@@ -927,9 +949,6 @@ add_event_clicked_cb (GcalYearView *year_view,
   GcalYearViewPrivate *priv = year_view->priv;
   icaltimetype *start_date, *end_date = NULL;
 
-  if (priv->popover_mode)
-    gtk_widget_hide (priv->popover);
-
   if (priv->start_selected_date->day == 0)
     {
       start_date = gcal_dup_icaltime (priv->current_date);
@@ -943,6 +962,9 @@ add_event_clicked_cb (GcalYearView *year_view,
       end_date->is_date = 1;
     }
 
+  if (priv->popover_mode)
+    gtk_widget_hide (priv->popover);
+
   start_date->is_date = 1;
   g_signal_emit_by_name (GCAL_VIEW (year_view), "create-event-detailed", start_date, end_date);
   g_free (start_date);
@@ -1016,10 +1038,13 @@ gcal_year_view_get_preferred_width (GtkWidget *widget,
                                     gint      *natural)
 {
   GcalYearViewPrivate *priv = GCAL_YEAR_VIEW (widget)->priv;
+  GtkStyleContext *context;
   gint padding_left;
 
-  gtk_style_context_get (gtk_widget_get_style_context (priv->navigator),
-                         gtk_widget_get_state_flags (priv->navigator),
+  context = gtk_widget_get_style_context (priv->navigator);
+
+  gtk_style_context_get (context,
+                         gtk_style_context_get_state (context),
                          "padding-left", &padding_left, NULL);
 
   if (minimum != NULL)
@@ -1035,10 +1060,13 @@ gcal_year_view_get_preferred_height_for_width (GtkWidget *widget,
                                                gint      *natural)
 {
   GcalYearViewPrivate *priv = GCAL_YEAR_VIEW (widget)->priv;
+  GtkStyleContext *context;
   gint padding_top;
 
-  gtk_style_context_get (gtk_widget_get_style_context (priv->navigator),
-                         gtk_widget_get_state_flags (priv->navigator),
+  context = gtk_widget_get_style_context (priv->navigator);
+
+  gtk_style_context_get (context,
+                         gtk_style_context_get_state (context),
                          "padding-top", &padding_top, NULL);
 
   if (minimum != NULL)
@@ -1058,7 +1086,7 @@ gcal_year_view_size_allocate (GtkWidget     *widget,
   context = gtk_widget_get_style_context (widget);
   gtk_style_context_save (context);
   gtk_style_context_add_class (context, "year-navigator");
-  gtk_style_context_get (context, gtk_widget_get_state_flags (widget), "padding-left", &padding_left, NULL);
+  gtk_style_context_get (context, gtk_style_context_get_state (context), "padding-left", &padding_left, NULL);
   gtk_style_context_restore (context);
 
   priv->popover_mode = (alloc->width < NAVIGATOR_CELL_WIDTH * 4 + padding_left * 8 + SIDEBAR_PREFERRED_WIDTH);
@@ -1309,6 +1337,8 @@ gcal_year_view_class_init (GcalYearViewClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, navigator_motion_notify_cb);
   gtk_widget_class_bind_template_callback (widget_class, add_event_clicked_cb);
   gtk_widget_class_bind_template_callback (widget_class, popover_closed_cb);
+
+  gtk_widget_class_set_css_name (widget_class, "calendar-view");
 }
 
 static void
@@ -1317,7 +1347,6 @@ gcal_year_view_init (GcalYearView *self)
   self->priv = gcal_year_view_get_instance_private (self);
 
   gtk_widget_init_template (GTK_WIDGET (self));
-  gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (self)), "calendar-view");
 
   if (gtk_widget_get_direction (GTK_WIDGET (self)) == GTK_TEXT_DIR_LTR)
     self->priv->k = 0;
